<?php
/*
Plugin Name: Default Twitter Image for Yoast
Plugin URI: https://whodunit.fr
Description: Provide a default Twitter Image setting for Yoast SEO. An unofficial Yoast add-on made with ♥️ by Whodunit.
Author: Jb Audras @ Whodunit
Version: 0.1
Plugin URI: https://whodunit.fr
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Donate link: https://paypal.me/audrasjb
Text Domain: default-twitter-image
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Resources enqueues
function dtify_enqueue_scripts( $hook ) {
	if ( 'seo_page_wpseo_social' !== $hook ) {
		return;
	}
	$translations = array(
		'dtify_ajax_url' => esc_url( admin_url( 'admin-ajax.php' ) ),
	);
	wp_localize_script( 'jquery', 'dtify_localize', $translations );
}
add_action( 'admin_enqueue_scripts', 'dtify_enqueue_scripts' );

// Display Twitter default image field on Yoast
function dtify_add_default_twitter_image() {
	$id_image = get_option( 'dtify_twitter_default_image_id', '' );
	$image_src = ( '' !== $id_image && wp_get_attachment_url( $id_image ) ) ? wp_get_attachment_url( $id_image ) : '';
	$style_display = ( empty( $image_src ) ) ? 'display:none;' : '';
	?>
	<h2><?php esc_html_e( 'Default settings', 'default-twitter-image' ); ?></h2>
	<label class="select" for="dtify_twitter_default_image"><?php esc_html_e( 'Image URL', 'default-twitter-image' ); ?></label>
	<span>
		<input class="textinput" id="dtify_twitter_default_image" type="text" size="36" name="dtify_twitter_default_image" value="<?php echo $image_src; ?>" readonly="readonly">
		<input id="dtify_upload_twitter_image" class="button" type="button" value="<?php esc_attr_e( 'Upload image', 'default-twitter-image' ); ?>">
		<input id="dtify_remove_twitter_image" class="dtify_image_remove_button button" type="button" value="<?php esc_attr_e( 'Clear image', 'default-twitter-image' ); ?>">
		<input type="hidden" id="dtify_twitter_default_image_id" name="dtify_twitter_default_image_id" value="">
	</span>
	<?php if ( $id_image > 0 ) : ?>
		<p><?php esc_html_e( 'Current default image:', 'default-twitter-image' ); ?></p>
	<?php endif; ?>
	<div class="image-preview-wrapper">
		<img id="image-preview" src="<?php echo esc_url( $image_src ); ?>" style="height:100px; <?php echo $style_display; ?>" />
	</div>
		<script type="text/javascript">
			jQuery(document).ready(function ($) {
				// Uploading files
				var file_frame;
				var wp_media_post_id = wp.media.model.settings.post.id; // Store the old id
				var set_to_post_id = '<?php echo (int) $id_image; ?>'; // Set this
				$('#dtify_upload_twitter_image').on('click', function (event) {
					event.preventDefault();
					// If the media frame already exists, reopen it.
					if (file_frame) {
						// Set the post ID to what we want
						file_frame.uploader.uploader.param('post_id', set_to_post_id);
						// Open frame
						file_frame.open();
						return;
					} else {
						// Set the wp.media post id so the uploader grabs the ID we want when initialised
						wp.media.model.settings.post.id = set_to_post_id;
					}
					// Create the media frame.
					file_frame = wp.media.frames.file_frame = wp.media({
						title: '<?php esc_html_e( 'Select an image to upload', 'default-twitter-image' ); ?>',
						button: {
							text: '<?php esc_html_e( 'Use this image', 'default-twitter-image' ); ?>',
						},
						multiple: false // Set to true to allow multiple files to be selected
					});
					// When an image is selected, run a callback.
					file_frame.on('select', function () {
						// We set multiple to false so only get one image from the uploader
						attachment = file_frame.state().get('selection').first().toJSON();
						// Do something with attachment.id and/or attachment.url here
						$('#image-preview').attr('src', attachment.url).css('width', 'auto');
						$('#image-preview').show();
						$('#dtify_twitter_default_image_id').val(attachment.id);
						$('#dtify_twitter_default_image_id').trigger('change');
						$('#dtify_twitter_default_image').val(attachment.link);
						// Restore the main post ID
						wp.media.model.settings.post.id = wp_media_post_id;
					});
					// Finally, open the modal
					file_frame.open();
				});
				// Restore the main ID when the add media button is pressed
				$('a.add_media').on('click', function () {
					wp.media.model.settings.post.id = wp_media_post_id;
				});
				// Clear image
				$('#dtify_remove_twitter_image').on('click', function(event){
					$('#dtify_twitter_default_image').val('');
					$('#dtify_twitter_default_image_id').val('0');
					$('#dtify_twitter_default_image_id').trigger('change');
					$('#image-preview').attr('src', '');
					$('#image-preview').hide();
				});
				// AJAX part
				$('#dtify_twitter_default_image_id').on('change', function() {
					var media_id = $(this).val();
					console.log(media_id);
					var data = {
						'action': 'dtify_update',
						'media_id': media_id,
					}
					$.ajax( {
						url: dtify_localize.dtify_ajax_url,
						type: 'post',
						data: data,
						success: function( response ) {
						},
						error: function( response ) {
						}
					} );
				} );

			});
		</script>
	<?php
}
add_action( 'wpseo_admin_twitter_section', 'dtify_add_default_twitter_image' );

// While we are there, let's also display the preview image on Facebook tab
function dtify_add_facebook_default_image_preview() {
	$id_image = get_option( 'dtify_twitter_default_image_id', '' );
	?>
	<?php if ( $id_image > 0 ) : ?>
	<p><?php esc_html_e( 'Current default image:', 'default-twitter-image' ); ?></p>
	<?php endif; ?>
	<div class="image-preview-wrapper">
	</div>
	<script>
	jQuery( document ).ready( function( $ ) {
		if ( $( '#wpseo_og_default_image' ).val().length > 0 ) {
			var image_src = $( '#wpseo_og_default_image' ).val();
			$( '#facebook .image-preview-wrapper' ).html( '<img id="image-preview" src="' + image_src + '" style="height:100px;" />' );
		}
		$( '#wpseo_og_default_image' ).on( 'change keyup paste', function() {
			if ( $( '#wpseo_og_default_image' ).val().length > 0 ) {
				var image_src = $( '#wpseo_og_default_image' ).val();
				$( '#facebook .image-preview-wrapper' ).html( '<img id="image-preview" src="' + image_src + '" style="height:100px;" />' );
			}
		});
	} );
	</script>
	<?php
}
add_action( 'wpseo_admin_opengraph_section', 'dtify_add_facebook_default_image_preview' );

// Display the default Twitter image on front
function dtify_default_twitter_image( $image ) {
	if ( ! $image ) {
		global $post;
		$image_infos = wp_get_attachment_image_src( get_option( 'dtify_twitter_default_image_id' ), 'full' );
		$image = $image_infos[0];
	}
	return $image; 
}; 
add_filter( 'wpseo_twitter_image', 'dtify_default_twitter_image' );

// Update the option using AJAX callback
function dtify_ajax_update() {
	$media_id = (int) ( filter_input( INPUT_POST, 'media_id', FILTER_SANITIZE_STRING ) );

	if ( ! empty( $media_id ) ) {
		update_option( 'dtify_twitter_default_image_id', $media_id );
		wp_send_json_success( 'success' );
	} elseif ( 0 === $media_id ) {
		update_option( 'dtify_twitter_default_image_id', '' );
		wp_send_json_success( 'success' );
	} else {
		wp_send_json_success( 'error' );
	}
	die();
}
add_action( 'wp_ajax_dtify_update', 'dtify_ajax_update' );
add_action( 'wp_ajax_nopriv_dtify_update', 'dtify_ajax_update' );